ShimRegisterAck

Struct ShimRegisterAck 

pub struct ShimRegisterAck {
    pub accepted: bool,
    pub daemon_version: String,
    pub reason: Option<String>,
    pub envelope_version: u32,
}
Server’s reply to ShimRegister. If accepted is false the server closes the connection after sending the ack and the shim client surfaces reason to its parent process. When accepted is true, reason is omitted from the wire form (skip-if-none).

Fields

accepted: booldaemon_version: Stringreason: Option<String>

Rejection reason. Omitted from the wire when accepted=true.

envelope_version: u32