pub struct ArtifactInputDigest {
pub schema_version: u32,
pub digest: String,
}Expand description
Digest of the manifest inputs that produced an ArtifactId.
Fields
schema_version: u32Manifest key schema version used to compute the digest.
digest: StringHex-encoded digest over the canonical artifact manifest inputs.